[Date Prev][Date Next] [Thread Prev][Thread Next] [Date Index] [Thread Index]

[dak/master] Rename 2 sequences in database upgrade #41.



Signed-off-by: Torsten Werner <twerner@debian.org>
---
 dak/dakdb/update41.py |    7 +++++--
 1 files changed, 5 insertions(+), 2 deletions(-)

diff --git a/dak/dakdb/update41.py b/dak/dakdb/update41.py
index de24a52..338648f 100755
--- a/dak/dakdb/update41.py
+++ b/dak/dakdb/update41.py
@@ -3,7 +3,7 @@
 
 """
 Remove useless type casts from primary keys to support sqlalchemy's
-reflection mechanism for all tables.
+reflection mechanism for all tables. Rename 2 sequences.
 
 @contact: Debian FTP Master <ftpmaster@debian.org>
 @copyright: 2011 Torsten Werner <twerner@debian.org>
@@ -33,7 +33,7 @@ from socket import gethostname;
 ################################################################################
 def do_update(self):
     """
     Remove useless type casts from primary keys.
     """
     print __doc__
     try:
@@ -46,6 +46,9 @@ def do_update(self):
             c.execute("ALTER TABLE %s ALTER id SET DEFAULT nextval('%s_id_seq'::regclass)" % \
                 (table, table))
 
+        c.execute("ALTER SEQUENCE known_changes_id_seq RENAME TO changes_id_seq")
+        c.execute("ALTER SEQUENCE queue_files_id_seq RENAME TO build_queue_files_id_seq")
+
         c.execute("UPDATE config SET value = '41' WHERE name = 'db_revision'")
         self.db.commit()
 
@@ -33,7 +33,7 @@ from socket import gethostname;
 def do_update(self):
     """
-    Remove useless type casts from primary keys.
+    Remove useless type casts from primary keys and fix 2 sequences.
     """
     print __doc__
-- 
1.5.6.5



Reply to: